@@ -5,11 +5,12 @@
 */
 
 #include "texttospeechconfigwidget.h"
-#include "abstracttexttospeechconfiginterface.h"
 #include "textedittexttospeech_debug.h"
 #include "texttospeechconfiginterface.h"
 #include "texttospeechlanguagecombobox.h"
 #include "texttospeechsliderwidget.h"
+#include "texttospeechvoicecombobox.h"
+
 #include "texttospeechutil.h"
 #include <KLocalizedString>
 
@@ -26,10 +27,10 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     , mVolume(new TextToSpeechSliderWidget(QStringLiteral("%1 %"), this))
     , mRate(new TextToSpeechSliderWidget(QStringLiteral("%1"), this))
     , mPitch(new TextToSpeechSliderWidget(QStringLiteral("%1"), this))
-    , mLanguage(new TextEditTextToSpeech::TextToSpeechLanguageComboBox(this))
-    , mAbstractTextToSpeechConfigInterface(new TextToSpeechConfigInterface(this))
+    , mLanguage(new TextToSpeechLanguageComboBox(this))
+    , mTextToSpeechConfigInterface(new TextToSpeechConfigInterface(this))
     , mAvailableEngine(new QComboBox(this))
-    , mVoice(new QComboBox(this))
+    , mVoice(new TextToSpeechVoiceComboBox(this))
     , mTestButton(new QPushButton(QIcon::fromTheme(QStringLiteral("player-volume")), i18n("Test"), this))
 {
     auto layout = new QFormLayout(this);
@@ -64,7 +65,6 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     mTestButton->setObjectName(QStringLiteral("mTestButton"));
     layout->addWidget(mTestButton);
     connect(mTestButton, &QPushButton::clicked, this, &TextToSpeechConfigWidget::slotTestTextToSpeech);
-
     QTimer::singleShot(0, this, &TextToSpeechConfigWidget::slotUpdateSettings);
 }
 
@@ -72,7 +72,6 @@ TextToSpeechConfigWidget::~TextToSpeechConfigWidget() = default;
 
 void TextToSpeechConfigWidget::initializeSettings()
 {
-    readConfig();
     slotAvailableEngineChanged();
 }
 
@@ -101,25 +100,34 @@ void TextToSpeechConfigWidget::updateLocale()
 
 void TextToSpeechConfigWidget::readConfig()
 {
-    KConfig config(TextEditTextToSpeech::TextToSpeechUtil::textToSpeechConfigFileName());
-    const KConfigGroup grp = config.group(TextEditTextToSpeech::TextToSpeechUtil::textToSpeechConfigGroupName());
-    const auto rate = grp.readEntry("rate", 0);
-    mRate->setValue(rate);
-    const auto pitch = grp.readEntry("pitch", 0);
-    mPitch->setValue(pitch);
-    mVolume->setValue(grp.readEntry("volume", 50));
+    const TextEditTextToSpeech::TextToSpeechUtil::TextToSpeechSettings settings = TextEditTextToSpeech::TextToSpeechUtil::loadSettings();
+    mRate->setValue(settings.rate);
+    mPitch->setValue(settings.pitch);
+    mVolume->setValue(settings.volumeValue);
+    mLanguage->selectLocaleName(settings.localeName);
+    const QString engineName = settings.engineName;
+    // qDebug() << " engineName " << engineName;
+    const int engineIndex = mAvailableEngine->findData(engineName);
+    // qDebug() << " engineIndex " << engineIndex;
+    if (engineIndex != -1) {
+        mAvailableEngine->setCurrentIndex(engineIndex);
+    }
+    // FIXME: list of voice is not loading here... need to fix it
+    mVoice->setCurrentVoice(settings.voice);
+    // qDebug() << " load settings " << settings;
 }
 
 void TextToSpeechConfigWidget::writeConfig()
 {
-    KConfig config(TextEditTextToSpeech::TextToSpeechUtil::textToSpeechConfigFileName());
-    KConfigGroup grp = config.group(TextEditTextToSpeech::TextToSpeechUtil::textToSpeechConfigGroupName());
-    grp.writeEntry("volume", mVolume->value());
-    grp.writeEntry("rate", mRate->value());
-    grp.writeEntry("pitch", mPitch->value());
-    grp.writeEntry("localeName", mLanguage->currentData().toLocale().name());
-    grp.writeEntry("engine", mAvailableEngine->currentData().toString());
-    grp.writeEntry("voice", mVoice->currentData().toString());
+    TextEditTextToSpeech::TextToSpeechUtil::TextToSpeechSettings settings;
+    settings.volumeValue = mVolume->value();
+    settings.rate = mRate->value();
+    settings.pitch = mPitch->value();
+    settings.localeName = mLanguage->currentData().toLocale().name();
+    settings.engineName = mAvailableEngine->currentData().toString();
+    settings.voice = mVoice->currentVoice();
+    // qDebug() << " save settings " << settings;
+    TextEditTextToSpeech::TextToSpeechUtil::writeConfig(std::move(settings));
 }
 
 void TextToSpeechConfigWidget::slotLocalesAndVoices()
@@ -132,12 +140,13 @@ void TextToSpeechConfigWidget::slotUpdateSettings()
 {
     updateAvailableEngine();
     slotLocalesAndVoices();
+    readConfig();
 }
 
-void TextToSpeechConfigWidget::setTextToSpeechConfigInterface(AbstractTextToSpeechConfigInterface *interface)
+void TextToSpeechConfigWidget::setTextToSpeechConfigInterface(TextToSpeechConfigInterface *interface)
 {
-    delete mAbstractTextToSpeechConfigInterface;
-    mAbstractTextToSpeechConfigInterface = interface;
+    delete mTextToSpeechConfigInterface;
+    mTextToSpeechConfigInterface = interface;
     slotLocalesAndVoices();
 }
 
@@ -157,15 +166,15 @@ void TextToSpeechConfigWidget::slotTestTextToSpeech()
     settings.pitch = mPitch->value();
     settings.volume = mVolume->value();
     settings.localeName = mLanguage->currentData().toLocale().name();
-    settings.voice = mVoice->currentData().toString();
+    settings.voice = mVoice->currentVoice();
     qCDebug(TEXTEDITTEXTTOSPEECH_LOG) << " settings " << settings;
-    mAbstractTextToSpeechConfigInterface->testEngine(settings);
+    mTextToSpeechConfigInterface->testEngine(settings);
 }
 
 void TextToSpeechConfigWidget::updateAvailableEngine()
 {
     mAvailableEngine->clear();
-    const QStringList lst = mAbstractTextToSpeechConfigInterface->availableEngines();
+    const QStringList lst = mTextToSpeechConfigInterface->availableEngines();
     for (const QString &engine : lst) {
         mAvailableEngine->addItem(engine, engine);
     }
@@ -175,12 +184,8 @@ void TextToSpeechConfigWidget::updateAvailableEngine()
 
 void TextToSpeechConfigWidget::updateAvailableVoices()
 {
-    mVoice->clear();
-    const QStringList lst = mAbstractTextToSpeechConfigInterface->availableVoices();
-    for (const QString &voice : lst) {
-        mVoice->addItem(voice, voice);
-    }
-    mVoice->setSizeAdjustPolicy(QComboBox::AdjustToContents);
+    const QVector<QVoice> voices = mTextToSpeechConfigInterface->availableVoices();
+    mVoice->updateVoices(voices);
     updateVoice();
 }
 
@@ -211,20 +216,26 @@ void TextToSpeechConfigWidget::updateEngine()
 void TextToSpeechConfigWidget::updateAvailableLocales()
 {
     mLanguage->clear();
-    const QVector<QLocale> locales = mAbstractTextToSpeechConfigInterface->availableLocales();
-    const QLocale current = mAbstractTextToSpeechConfigInterface->locale();
+    const QVector<QLocale> locales = mTextToSpeechConfigInterface->availableLocales();
+    const QLocale current = mTextToSpeechConfigInterface->locale();
     mLanguage->updateAvailableLocales(locales, current);
     updateLocale();
 }
 
 void TextToSpeechConfigWidget::slotEngineChanged()
 {
-    mAbstractTextToSpeechConfigInterface->setEngine(mAvailableEngine->currentData().toString());
+    const QString newEngineName = mAvailableEngine->currentData().toString();
+    qCDebug(TEXTEDITTEXTTOSPEECH_LOG) << "newEngineName " << newEngineName;
+    mTextToSpeechConfigInterface->setEngine(newEngineName);
+    updateAvailableLocales();
+    slotLocalesAndVoices();
 }
 
 void TextToSpeechConfigWidget::slotLanguageChanged()
 {
     // QLocale locale = mLanguage->currentData().value<QLocale>();
+    // TODO
+    qCWarning(TEXTEDITTEXTTOSPEECH_LOG) << "slotLanguageChanged: not implemented yet";
 }
 
 #include "moc_texttospeechconfigwidget.cpp"
