@@ -38,12 +38,17 @@ TextTranslator::TranslatorEnginePlugin *LingvaEngineClient::createTranslator()
     return enginePlugin;
 }
 
-QMap<TextTranslator::TranslatorUtil::Language, QString> LingvaEngineClient::supportedLanguages()
+QMap<TextTranslator::TranslatorUtil::Language, QString> LingvaEngineClient::supportedFromLanguages()
 {
-    if (mLanguages.isEmpty()) {
-        mLanguages = fillLanguages();
+    if (mFromLanguages.isEmpty()) {
+        mFromLanguages = fillLanguages();
     }
-    return mLanguages;
+    return mFromLanguages;
+}
+
+QMap<TextTranslator::TranslatorUtil::Language, QString> LingvaEngineClient::supportedToLanguages()
+{
+    return supportedFromLanguages();
 }
 
 bool LingvaEngineClient::hasConfigurationDialog() const
@@ -51,8 +56,9 @@ bool LingvaEngineClient::hasConfigurationDialog() const
     return true;
 }
 
-void LingvaEngineClient::showConfigureDialog(QWidget *parentWidget)
+bool LingvaEngineClient::showConfigureDialog(QWidget *parentWidget)
 {
+    bool settingsChanged = false;
     QPointer<LingvaEngineDialog> dlg = new LingvaEngineDialog(parentWidget);
     KConfigGroup myGroup(KSharedConfig::openConfig(), LingvaEngineUtil::groupName());
     QString lingvaUrl = myGroup.readEntry(LingvaEngineUtil::serverUrlKey(), LingvaEngineUtil::defaultServerUrl());
@@ -65,8 +71,15 @@ void LingvaEngineClient::showConfigureDialog(QWidget *parentWidget)
         myGroup.writeEntry(LingvaEngineUtil::serverUrlKey(), serverUrl);
         myGroup.sync();
         Q_EMIT configureChanged();
+        settingsChanged = true;
     }
     delete dlg;
+    return settingsChanged;
+}
+
+TextTranslator::TranslatorEngineClient::EngineType LingvaEngineClient::engineType() const
+{
+    return TextTranslator::TranslatorEngineClient::Network;
 }
 
 bool LingvaEngineClient::isSupported(TextTranslator::TranslatorUtil::Language lang) const
